@@ -1,11 +1,11 @@
 package Dist::Zilla::Plugin::Test::CheckDeps;
 {
-  $Dist::Zilla::Plugin::Test::CheckDeps::VERSION = '0.003';
+  $Dist::Zilla::Plugin::Test::CheckDeps::VERSION = '0.004';
 }
 
 use Moose;
 extends qw/Dist::Zilla::Plugin::InlineFiles/;
-with qw/Dist::Zilla::Role::TextTemplate/;
+with qw/Dist::Zilla::Role::TextTemplate Dist::Zilla::Role::PrereqSource/;
 
 has fatal => (
 	is => 'ro',
@@ -23,6 +23,11 @@ around add_file => sub {
 	);
 };
 
+sub register_prereqs {
+	my $self = shift;
+	$self->zilla->register_prereqs({ phase => 'test' }, 'Test::More' => 0.88, 'Test::CheckDeps' => 0.002);
+}
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
@@ -38,7 +43,7 @@ Dist::Zilla::Plugin::Test::CheckDeps
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 AUTHOR
 
@@ -80,3 +85,9 @@ __END__
 
 This module adds a test that assures all dependencies have been installed properly. If requested, it can bail out all testing on error.
 
+__END__
+
+=for Pod::Coverage
+register_prereqs
+=end
+
